#
# spec file for package libnet
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libnet9
%define realver 1.2-rc3
Name:           libnet
Version:        1.2~rc3
Release:        1.29
Summary:        A C Library for Portable Packet Creation
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            http://sourceforge.net/projects/libnet-dev
Source0:        http://downloads.sourceforge.net/libnet-dev/%{name}-%{realver}.tar.gz
#PATCH-FIX-OPENSUSE: tchvatal@suse.com, use proper version string to work fine
Patch0:         libnet-1.2-rc.patch
#PATCH-FIX-OPENSUSE: tchvatal@suse.com, properly detect PF_PACKET in OBS
# Not upstreamable as we simply expect the feature to be there
Patch1:         libnet-pf-packet.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libnet is an API to help with the construction and handling of network
packets. It provides a portable framework for low-level network packet
writing and handling. Libnet includes packet creation at the IP layer
and at the link layer as well as a host of supplementary and
complementary functionality. Libnet is very useful for writing network
tools and network test code. See the man page and sample test code for
more detailed information.

%package -n %{libname}
Summary:        A C Library for Portable Packet Creation
Group:          Development/Libraries/C and C++

%description -n %{libname}
Libnet is an API to help with the construction and handling of network
packets. It provides a portable framework for low-level network packet
writing and handling. Libnet includes packet creation at the IP layer
and at the link layer as well as a host of supplementary and
complementary functionality. Libnet is very useful for writing network
tools and network test code. See the man page and sample test code for
more detailed information.

%package devel
Summary:        Devel files for libnet
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
Libnet is an API to help with the construction and handling of network
packets. This package contains devel files.

%package doc
Summary:        Documentation for libnet
Group:          Development/Libraries/C and C++

%description doc
Libnet is an API to help with the construction and handling of network
packets. This package contains documentation.

%prep
%setup -q -n %{name}-%{realver}
%patch0 -p1
%patch1 -p1

rm -rf sample/win32
# HACK: to have samples/ dir untouched and ready for installation
cp -r sample sample_doc

%build
# no configure in a tarball
autoreconf -fiv
CFLAGS="%{optflags} -Wall -Wno-unused" \
%configure \
    --disable-static \
    --with-pic \
    --with-link-layer=linux
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print
install -d -m 755 %{buildroot}/%{_bindir}
install -m 755 libnet-config %{buildroot}/%{_bindir}

rm -rf sample/
# HACK: rename untouched dir back
mv sample_doc sample
find doc/  -name "Makefile*" -o -name ".libs" | xargs rm -rf

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%doc doc/COPYING
%{_libdir}/libnet.so.*

%files devel
%defattr(-,root,root)
%{_bindir}/libnet-config
%{_includedir}/libnet*
%{_libdir}/libnet.so
%{_mandir}/man3/*

%files doc
%defattr(-,root,root)
%doc doc/* sample

%changelog
* Fri Oct 23 2015 tchvatal@suse.com
- Add patch for bnc#949391:
  * libnet-pf-packet.patch
* Fri Mar 13 2015 tchvatal@suse.com
- Remove no longer needed provide/obsolete
* Tue May 13 2014 tchvatal@suse.com
- Drop patch removing manpages, no reason to remove them.
  libnet-1.2.0-drop-man-build.patch
* Tue May 13 2014 tchvatal@suse.com
- Update to actual released tarball which is versioned 1.2-rc3
- Cleanup with spec-cleaner
- No reason to not have this library in /usr so move it there
- Add patch libnet-1.2-rc.patch needed to set proper version in
  automake.
* Thu Jan  2 2014 mvyskocil@suse.com
- Use macro in libnet-devel to ensure correct dependency
* Thu Dec 19 2013 mvyskocil@suse.com
- Update to 1.2
  no changelog available
- add libnet-1.2.0-drop-man-build.patch to not fail on non existing
  manual pages
* Thu Oct  3 2013 mvyskocil@suse.com
- Install just plain c files in samples/
* Wed Mar 27 2013 mvyskocil@suse.com
- update to 1.1.6
  * obsoleted libnet-1.1.2.1-uninitialized-fix.diff
  * obsoleted libnet-1.1.5-arrray-fix.diff
  * fixes the PF_PACKET detection (bnc#810138)
  * includes many bugfixes from Debian
  * ICMPv6 and IPv6 related bugfixes
  * and many more
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Nov 20 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu May  5 2011 dmueller@suse.de
- complete package rename to libnet1
* Wed Feb  9 2011 adam@mizerski.pl
- minor specfile improvements
- removed dead/unused libnet-1.1.5-strict-aliasing-fix.diff
* Sat Nov 20 2010 coolo@novell.com
- fix requires of devel package
* Fri Nov 19 2010 mvyskocil@suse.cz
- update to 1.1.5 (from libnet-dev.sf.net) a bugfix release
  see CHANGELOG for complete list of fixes from 1.1.2.1
- patches changes:
  * remove libnet-endianess-fix.diff
  * remove libnet-shared.diff
  * remove libnet-1.1.2.1-makefile.diff
  * refresh libnet-1.1.5-strict-aliasing-fix.diff
  * refresh libnet-1.1.5-arrray-fix.diff
- rename to libnet1 to conforms Shared Library Policy
- split devel files to libnet-devel and documentation to libnet-doc
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Sep  9 2008 crrodriguez@suse.de
- after removing static libraries, syslog-ng complains that are
  needed, so we move the shared library to /%%{_lib} to really fix
  the problem
* Thu Sep  4 2008 crrodriguez@suse.de
- remove "la" file with empty dependency_libs
- disable static libraries
- libpcap is no longer needed for this package
- configure option --with-pf_packet does not exists anymore
* Wed Mar 14 2007 anosek@suse.cz
- fixed permissions of man pages [#254335]
* Fri Feb 17 2006 lmichnovic@suse.cz
- fixed subscription beyond array and uninitialized variable [#151312]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep 19 2005 mmarek@suse.cz
- fixed some gcc warnings
* Thu Nov 18 2004 ro@suse.de
- fixed file list
* Wed Aug  4 2004 postadal@suse.cz
- updated to version 1.1.2.1
* Wed Feb 11 2004 postadal@suse.cz
- removed compiled files from /usr/share/doc/packages/libnet/sample
* Tue Feb 10 2004 postadal@suse.cz
- updated to version 1.1.1
- removed obsoleted patches: autoconf-fix.diff, samples.diff
- fixed code that broke strict aliasing
* Sun Jan 11 2004 adrian@suse.de
- add %%run_ldconfig
* Wed Aug 13 2003 mjancar@suse.cz
- build also shared library
* Thu Jul 24 2003 meissner@suse.de
- honor detected endianess.
* Thu Jul 24 2003 postadal@suse.cz
- update to version 1.1.0
* Mon Nov 11 2002 postadal@suse.cz
- fixed deprecated multiline string literals
* Wed Jan  9 2002 cihlar@suse.cz
- use %%{_libdir}
* Wed Feb 14 2001 cihlar@suse.cz
- update to version 1.0.2a
- clean up spec file
* Thu Nov 16 2000 grimmer@suse.de
- initial package (version 1.0.1b)
